@@ -3,7 +3,10 @@
 import { NativeModules } from 'react-native';
 import type {
   sourceType,
-  trimOptions
+  trimOptions,
+  previewMaxSize,
+  format,
+  cropOptions
 } from './types';
 
 import { getActualSource } from '../utils';
@@ -16,11 +19,19 @@ class ProcessingManager {
     return TrimmerManager.trim(mData)
       .then((res) => res.source);
   }
-  static compress(source: sourceType, options: any): Promise<*> {
+
+  static getPreviewForSecond(
+    source: sourceType,
+    second: number,
+    maximumSize: previewMaxSize,
+    format: format
+  ): Promise<*> {
     const actualSource: string = getActualSource(source);
-    const mData = { source: actualSource, ...options };
-    return TrimmerManager.compress(mData);
+    const mData = { source: actualSource, second, format };
+    return TrimmerManager.getPreviewImageAtPosition(mData)
+      .then((res) => res.image);
   }
+
   static getVideoInfo(source: sourceType): Promise<*> {
     const actualSource: string = getActualSource(source);
     return TrimmerManager.getVideoInfo(actualSource)
@@ -29,12 +40,19 @@ class ProcessingManager {
         size
       }));
   }
-  static getPreviewForSecond(source: sourceType, second: number): Promise<*> {
+
+  static compress(source: sourceType, options: any): Promise<*> {
     const actualSource: string = getActualSource(source);
-    const mData = { source: actualSource, second };
-    return TrimmerManager.getPreviewImageAtPosition(mData)
-      .then((res) => res.image);
+    const mData = { source: actualSource, ...options };
+    return TrimmerManager.compress(mData);
   }
+
+  static crop(source: sourceType, options: cropOptions): Promise<string> {
+    const actualSource: string = getActualSource(source);
+    return TrimmerManager.crop(actualSource, options)
+      .then((res) => res.source);
+  }
+
 }
 
 export default ProcessingManager;
